@@ -17,7 +17,7 @@
 
 from twitter import Api
 import readrss
-from shortener import services
+from shortener import services, ShortenerException
 from httplib import BadStatusLine
 from urllib2 import HTTPError, URLError
 import time
@@ -49,10 +49,14 @@ class Microblog(object):
             self.postIt(reversed(lista[:self.items]))
 
     def postIt(self, items):
-        oldItems = pItems=0
+        oldItems = pItems = 0
         for it in list(items):
             if self.mode == 'title':
-                txt = it["title"][0:114] + " " + self.shortener.short(it["link"])
+                try:
+                    short_address = self.shortener.short(it["link"])	   
+                except (ShortenerException):
+                    continue
+                txt = it["title"][0:114] + " " + short_address
             elif self.mode == 'text':
                 try:
                     txt = self.strip_tags(it.content[0].value)[0:140]
@@ -68,7 +72,7 @@ class Microblog(object):
 
             except (BadStatusLine, HTTPError, URLError):
                 #lets try in the next time
-                return
+                continue
 
 class WordpressAPI(object):
     def __init__(self,username = None, password = None, xmlrpc_url = None):
