@@ -18,15 +18,21 @@
 import urllib
 from xml.dom.minidom import parseString
 
+class ShortenerException(Exception):
+    pass
+
 class TinyURL(object):
     def short(self,url):
         try:
             params = urllib.urlencode({'url':url})
             fp = urllib.urlopen("http://tinyurl.com/api-create.php", params)
-            return fp.read()
+	    short_url = fp.read()
+	    if 'http' not in short_url:
+                raise ShortenerException('tinyurl error')
+            return short_url
 
         except IOError, e:
-            raise "urllib error."
+            raise ShortenerException('tinyurl error')
 
 class IsGD(object):
     def short(self,url):
@@ -34,10 +40,13 @@ class IsGD(object):
             params = urllib.urlencode({'longurl':url})
             url = "http://is.gd/api.php?%s" % params
             fp = urllib.urlopen(url)
-            return fp.read()
+	    short_url = fp.read()
+	    if 'http' not in short_url:
+                raise ShortenerException('tinyurl error')
+	    return short_url
 
         except IOError, e:
-            raise "urllib error."
+            raise ShortenerException('Is.gd error')
 
 class MigreME(object):
     def short(self,url):
@@ -46,10 +55,13 @@ class MigreME(object):
             url = "http://migre.me/api.xml?%s" % params
             fp = urllib.urlopen(url)
             dom = parseString(fp.read())
-            return dom.getElementsByTagName('migre')[0].childNodes[0].data
+	    short_url = dom.getElementsByTagName('migre')[0].childNodes[0].data
+	    if 'http' not in short_url:
+                raise ShortenerException('tinyurl error')
+	    return short_url
 
         except IOError, e:
-            raise "urllib error."
+            raise ShortenerException('migreme error')
 
 services = {
     'tinyurl' : TinyURL,
